==> google_cloud_netapp-0.3.17.tar.gz: google_cloud_netapp-0.3.17/google/cloud/netapp_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .active_directory import (
    ActiveDirectory,
    CreateActiveDirectoryRequest,
    DeleteActiveDirectoryRequest,
    GetActiveDirectoryRequest,
    ListActiveDirectoriesRequest,
    ListActiveDirectoriesResponse,
    UpdateActiveDirectoryRequest,
)
from .backup import (
    Backup,
    CreateBackupRequest,
    DeleteBackupRequest,
    GetBackupRequest,
    ListBackupsRequest,
    ListBackupsResponse,
    UpdateBackupRequest,
)
from .backup_policy import (
    BackupPolicy,
    CreateBackupPolicyRequest,
    DeleteBackupPolicyRequest,
    GetBackupPolicyRequest,
    ListBackupPoliciesRequest,
    ListBackupPoliciesResponse,
    UpdateBackupPolicyRequest,
)
from .backup_vault import (
    BackupVault,
    CreateBackupVaultRequest,
    DeleteBackupVaultRequest,
    GetBackupVaultRequest,
    ListBackupVaultsRequest,
    ListBackupVaultsResponse,
    UpdateBackupVaultRequest,
)
from .cloud_netapp_service import OperationMetadata
from .common import EncryptionType, LocationMetadata, ServiceLevel
from .kms import (
    CreateKmsConfigRequest,
    DeleteKmsConfigRequest,
    EncryptVolumesRequest,
    GetKmsConfigRequest,
    KmsConfig,
    ListKmsConfigsRequest,
    ListKmsConfigsResponse,
    UpdateKmsConfigRequest,
    VerifyKmsConfigRequest,
    VerifyKmsConfigResponse,
)
from .replication import (
    CreateReplicationRequest,
    DeleteReplicationRequest,
    DestinationVolumeParameters,
    EstablishPeeringRequest,
    GetReplicationRequest,
    HybridPeeringDetails,
    ListReplicationsRequest,
    ListReplicationsResponse,
    Replication,
    ResumeReplicationRequest,
    ReverseReplicationDirectionRequest,
    StopReplicationRequest,
    SyncReplicationRequest,
    TransferStats,
    UpdateReplicationRequest,
)
from .snapshot import (
    CreateSnapshotRequest,
    DeleteSnapshotRequest,
    GetSnapshotRequest,
    ListSnapshotsRequest,
    ListSnapshotsResponse,
    Snapshot,
    UpdateSnapshotRequest,
)
from .storage_pool import (
    CreateStoragePoolRequest,
    DeleteStoragePoolRequest,
    GetStoragePoolRequest,
    ListStoragePoolsRequest,
    ListStoragePoolsResponse,
    StoragePool,
    SwitchActiveReplicaZoneRequest,
    UpdateStoragePoolRequest,
)
from .volume import (
    AccessType,
    BackupConfig,
    CreateVolumeRequest,
    DailySchedule,
    DeleteVolumeRequest,
    ExportPolicy,
    GetVolumeRequest,
    HourlySchedule,
    HybridReplicationParameters,
    ListVolumesRequest,
    ListVolumesResponse,
    MonthlySchedule,
    MountOption,
    Protocols,
    RestoreParameters,
    RestrictedAction,
    RevertVolumeRequest,
    SecurityStyle,
    SimpleExportPolicyRule,
    SMBSettings,
    SnapshotPolicy,
    TieringPolicy,
    UpdateVolumeRequest,
    Volume,
    WeeklySchedule,
)

__all__ = (
    "ActiveDirectory",
    "CreateActiveDirectoryRequest",
    "DeleteActiveDirectoryRequest",
    "GetActiveDirectoryRequest",
    "ListActiveDirectoriesRequest",
    "ListActiveDirectoriesResponse",
    "UpdateActiveDirectoryRequest",
    "Backup",
    "CreateBackupRequest",
    "DeleteBackupRequest",
    "GetBackupRequest",
    "ListBackupsRequest",
    "ListBackupsResponse",
    "UpdateBackupRequest",
    "BackupPolicy",
    "CreateBackupPolicyRequest",
    "DeleteBackupPolicyRequest",
    "GetBackupPolicyRequest",
    "ListBackupPoliciesRequest",
    "ListBackupPoliciesResponse",
    "UpdateBackupPolicyRequest",
    "BackupVault",
    "CreateBackupVaultRequest",
    "DeleteBackupVaultRequest",
    "GetBackupVaultRequest",
    "ListBackupVaultsRequest",
    "ListBackupVaultsResponse",
    "UpdateBackupVaultRequest",
    "OperationMetadata",
    "LocationMetadata",
    "EncryptionType",
    "ServiceLevel",
    "CreateKmsConfigRequest",
    "DeleteKmsConfigRequest",
    "EncryptVolumesRequest",
    "GetKmsConfigRequest",
    "KmsConfig",
    "ListKmsConfigsRequest",
    "ListKmsConfigsResponse",
    "UpdateKmsConfigRequest",
    "VerifyKmsConfigRequest",
    "VerifyKmsConfigResponse",
    "CreateReplicationRequest",
    "DeleteReplicationRequest",
    "DestinationVolumeParameters",
    "EstablishPeeringRequest",
    "GetReplicationRequest",
    "HybridPeeringDetails",
    "ListReplicationsRequest",
    "ListReplicationsResponse",
    "Replication",
    "ResumeReplicationRequest",
    "ReverseReplicationDirectionRequest",
    "StopReplicationRequest",
    "SyncReplicationRequest",
    "TransferStats",
    "UpdateReplicationRequest",
    "CreateSnapshotRequest",
    "DeleteSnapshotRequest",
    "GetSnapshotRequest",
    "ListSnapshotsRequest",
    "ListSnapshotsResponse",
    "Snapshot",
    "UpdateSnapshotRequest",
    "CreateStoragePoolRequest",
    "DeleteStoragePoolRequest",
    "GetStoragePoolRequest",
    "ListStoragePoolsRequest",
    "ListStoragePoolsResponse",
    "StoragePool",
    "SwitchActiveReplicaZoneRequest",
    "UpdateStoragePoolRequest",
    "BackupConfig",
    "CreateVolumeRequest",
    "DailySchedule",
    "DeleteVolumeRequest",
    "ExportPolicy",
    "GetVolumeRequest",
    "HourlySchedule",
    "HybridReplicationParameters",
    "ListVolumesRequest",
    "ListVolumesResponse",
    "MonthlySchedule",
    "MountOption",
    "RestoreParameters",
    "RevertVolumeRequest",
    "SimpleExportPolicyRule",
    "SnapshotPolicy",
    "TieringPolicy",
    "UpdateVolumeRequest",
    "Volume",
    "WeeklySchedule",
    "AccessType",
    "Protocols",
    "RestrictedAction",
    "SecurityStyle",
    "SMBSettings",
)

==> google_cloud_netapp-0.3.18.tar.gz: google_cloud_netapp-0.3.18/google/cloud/netapp_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .active_directory import (
    ActiveDirectory,
    CreateActiveDirectoryRequest,
    DeleteActiveDirectoryRequest,
    GetActiveDirectoryRequest,
    ListActiveDirectoriesRequest,
    ListActiveDirectoriesResponse,
    UpdateActiveDirectoryRequest,
)
from .backup import (
    Backup,
    CreateBackupRequest,
    DeleteBackupRequest,
    GetBackupRequest,
    ListBackupsRequest,
    ListBackupsResponse,
    UpdateBackupRequest,
)
from .backup_policy import (
    BackupPolicy,
    CreateBackupPolicyRequest,
    DeleteBackupPolicyRequest,
    GetBackupPolicyRequest,
    ListBackupPoliciesRequest,
    ListBackupPoliciesResponse,
    UpdateBackupPolicyRequest,
)
from .backup_vault import (
    BackupVault,
    CreateBackupVaultRequest,
    DeleteBackupVaultRequest,
    GetBackupVaultRequest,
    ListBackupVaultsRequest,
    ListBackupVaultsResponse,
    UpdateBackupVaultRequest,
)
from .cloud_netapp_service import OperationMetadata
from .common import DirectoryServiceType, EncryptionType, LocationMetadata, ServiceLevel
from .kms import (
    CreateKmsConfigRequest,
    DeleteKmsConfigRequest,
    EncryptVolumesRequest,
    GetKmsConfigRequest,
    KmsConfig,
    ListKmsConfigsRequest,
    ListKmsConfigsResponse,
    UpdateKmsConfigRequest,
    VerifyKmsConfigRequest,
    VerifyKmsConfigResponse,
)
from .replication import (
    CreateReplicationRequest,
    DeleteReplicationRequest,
    DestinationVolumeParameters,
    EstablishPeeringRequest,
    GetReplicationRequest,
    HybridPeeringDetails,
    ListReplicationsRequest,
    ListReplicationsResponse,
    Replication,
    ResumeReplicationRequest,
    ReverseReplicationDirectionRequest,
    StopReplicationRequest,
    SyncReplicationRequest,
    TransferStats,
    UpdateReplicationRequest,
)
from .snapshot import (
    CreateSnapshotRequest,
    DeleteSnapshotRequest,
    GetSnapshotRequest,
    ListSnapshotsRequest,
    ListSnapshotsResponse,
    Snapshot,
    UpdateSnapshotRequest,
)
from .storage_pool import (
    CreateStoragePoolRequest,
    DeleteStoragePoolRequest,
    GetStoragePoolRequest,
    ListStoragePoolsRequest,
    ListStoragePoolsResponse,
    StoragePool,
    SwitchActiveReplicaZoneRequest,
    UpdateStoragePoolRequest,
    ValidateDirectoryServiceRequest,
)
from .volume import (
    AccessType,
    BackupConfig,
    CreateVolumeRequest,
    DailySchedule,
    DeleteVolumeRequest,
    ExportPolicy,
    GetVolumeRequest,
    HourlySchedule,
    HybridReplicationParameters,
    ListVolumesRequest,
    ListVolumesResponse,
    MonthlySchedule,
    MountOption,
    Protocols,
    RestoreParameters,
    RestrictedAction,
    RevertVolumeRequest,
    SecurityStyle,
    SimpleExportPolicyRule,
    SMBSettings,
    SnapshotPolicy,
    TieringPolicy,
    UpdateVolumeRequest,
    Volume,
    WeeklySchedule,
)

__all__ = (
    "ActiveDirectory",
    "CreateActiveDirectoryRequest",
    "DeleteActiveDirectoryRequest",
    "GetActiveDirectoryRequest",
    "ListActiveDirectoriesRequest",
    "ListActiveDirectoriesResponse",
    "UpdateActiveDirectoryRequest",
    "Backup",
    "CreateBackupRequest",
    "DeleteBackupRequest",
    "GetBackupRequest",
    "ListBackupsRequest",
    "ListBackupsResponse",
    "UpdateBackupRequest",
    "BackupPolicy",
    "CreateBackupPolicyRequest",
    "DeleteBackupPolicyRequest",
    "GetBackupPolicyRequest",
    "ListBackupPoliciesRequest",
    "ListBackupPoliciesResponse",
    "UpdateBackupPolicyRequest",
    "BackupVault",
    "CreateBackupVaultRequest",
    "DeleteBackupVaultRequest",
    "GetBackupVaultRequest",
    "ListBackupVaultsRequest",
    "ListBackupVaultsResponse",
    "UpdateBackupVaultRequest",
    "OperationMetadata",
    "LocationMetadata",
    "DirectoryServiceType",
    "EncryptionType",
    "ServiceLevel",
    "CreateKmsConfigRequest",
    "DeleteKmsConfigRequest",
    "EncryptVolumesRequest",
    "GetKmsConfigRequest",
    "KmsConfig",
    "ListKmsConfigsRequest",
    "ListKmsConfigsResponse",
    "UpdateKmsConfigRequest",
    "VerifyKmsConfigRequest",
    "VerifyKmsConfigResponse",
    "CreateReplicationRequest",
    "DeleteReplicationRequest",
    "DestinationVolumeParameters",
    "EstablishPeeringRequest",
    "GetReplicationRequest",
    "HybridPeeringDetails",
    "ListReplicationsRequest",
    "ListReplicationsResponse",
    "Replication",
    "ResumeReplicationRequest",
    "ReverseReplicationDirectionRequest",
    "StopReplicationRequest",
    "SyncReplicationRequest",
    "TransferStats",
    "UpdateReplicationRequest",
    "CreateSnapshotRequest",
    "DeleteSnapshotRequest",
    "GetSnapshotRequest",
    "ListSnapshotsRequest",
    "ListSnapshotsResponse",
    "Snapshot",
    "UpdateSnapshotRequest",
    "CreateStoragePoolRequest",
    "DeleteStoragePoolRequest",
    "GetStoragePoolRequest",
    "ListStoragePoolsRequest",
    "ListStoragePoolsResponse",
    "StoragePool",
    "SwitchActiveReplicaZoneRequest",
    "UpdateStoragePoolRequest",
    "ValidateDirectoryServiceRequest",
    "BackupConfig",
    "CreateVolumeRequest",
    "DailySchedule",
    "DeleteVolumeRequest",
    "ExportPolicy",
    "GetVolumeRequest",
    "HourlySchedule",
    "HybridReplicationParameters",
    "ListVolumesRequest",
    "ListVolumesResponse",
    "MonthlySchedule",
    "MountOption",
    "RestoreParameters",
    "RevertVolumeRequest",
    "SimpleExportPolicyRule",
    "SnapshotPolicy",
    "TieringPolicy",
    "UpdateVolumeRequest",
    "Volume",
    "WeeklySchedule",
    "AccessType",
    "Protocols",
    "RestrictedAction",
    "SecurityStyle",
    "SMBSettings",
)
